
 /*+-------------------------------------------------------+
   |  SAS Global Forum 2012 Sample                         |
   |  Together at Last: Spatial Analysis and SAS Mapping   |          
   |                                                       |
   |    NAME: SASGraphMap.sas                              |
   |   TITLE: Produce a heat map from results of           |
   |          Spatial Analysis.                            |
   | PRODUCT: GRAPH                                        |
   | PAPER TITLE:                                          |
   |   Together at Last: Spatial Analysis and SAS Mapping  |
   |                                                       |
   | NOTE:  You must run SpatialStat.sas first to create   |
   | the work.outOil data set used here.                   |
   | This program expects you to run from the directory    |
   | containing all programs and data sets.  Otherwise,    |
   | modify the program.                                   |
   |                                                       |
   |15March2012                                            |
   +-------------------------------------------------------+*/

/* location of the macro programs */
%include 'mpmacros.sas';
filename odsout '.'; /* HTML Output location */

/* Setup data set for creating map */
data bpmPlotData;
   set outOil;
   bpm = exp(Estimate);
   logbpm = Estimate;
   stdErrOrg = exp(StdErr);
   Longitude = gxc;
   Latitude = gyc;
run;

/*name of dataset with oil data*/
%let oildata=bpmPlotData;
%let predvar=logbpm;
/*%let predvar=bpm; */


/***********************************************
 * Prepare Grid                                *
 ***********************************************/

/***
%let maxval = 12.9;
%let minval = -10.8;
***/

/*set macro variables maxval and minval */
%get_minmax(&oildata,&predvar);


/* Set colors on the grid that we will draw    */
/* This will ramp the negative colors as green */
/* Neutral values (zero) is black              */
/* Positive colors are red                     */
data grid; 
  set &oildata; 
  length hx $2;

  /*make negative numbers green to black */
  /*the more negative the number, the greener */
  if (&predvar < 0) then do;
     cnum=(&predvar * (255/&minval));  /*scale colors */

	 /*Make sure we stay within the threshold values*/
	 if (cnum < 0) then cnum=0;
	 else if (cnum > 255) then cnum=255;
	 hx=put(cnum,hex2.);
	 /* Transparency for 9.3 and up*/
	 color="RGBA00"||trim(left(hx))||"0099";

	 /* Pre-9.3 cannot use transparency ****
	 color="CX00"||trim(left(hx))||"00";
	 ***/
	 end;

  /* Make Positive values black to Red */
  /* Larger numbers are more red       */
  else do;
     cnum=(&predvar * (255/ &maxval));
	 /*Make sure we stay within the threshold values*/
	 if (cnum < 0) then cnum=0;
	 else if (cnum > 255) then cnum=255;
	 hx=put(cnum,hex2.);
         /* Transparency for 9.3 and up*/
	 color="RGBA"||trim(left(hx))||"000099";
	
	 /* Pre-9.3 cannot use transparency ****
	 color ="CX"||trim(left(hx))||"0000";
	 ***/
     end;
  x=longitude; y=latitude;  /* use x and y values for GMAP */	
run;

/* Create annotate Rectangles for each point in the grid data set  */
/* outputds, inputds, width, height, linecolor, fillcolor,Solid?,Center?,tooltip value */
%make_rectangle(annogrid,grid,.1,.1,color,color,'Y','N',&predvar);

/***********************************************
 * Prepare Map Data                            *
 ***********************************************/

/* convert this map from Radians to Degrees to match the grid data */
%to_degrees(mystates, maps.states);

/* Crop the map */
proc gproject data=mystates out=mystates dupok project=none
  longmin=-98 longmax=-85 latmin=2 latmax=35;
  id state;
run;

/***********************************************
 * Draw the map and heat-map                   *
 ***********************************************/
/*Mapdata, responsedata, annotatedata, id, choro, filename, device, mapcolor?*/
%draw_map(mystates,mystates,annogrid,state,state,oil,png,"Y");
