
 /*+-------------------------------------------------------+
   |  SAS Global Forum 2012 Sample                         |
   |  Together at Last: Spatial Analysis and SAS Mapping   |          
   |                                                       |
   |    NAME: SpatialStat.sas                              |
   |   TITLE: Perform Spatial Analysis                     |
   | PRODUCT: GRAPH, STAT, SAS                             |
   | PAPER TITLE:                                          |
   |   Together at Last: Spatial Analysis and SAS Mapping  |
   |                                                       |
   | NOTE:  You must run this program before               |
   | SpatialStat.sas to create the work.outOil data set.   |
   | This program expects you to run from the directory    |
   | containing all programs and data sets.  Otherwise,    |
   | modify the program.                                   |
   |15March2012                                            |
   +-------------------------------------------------------+*/
libname oilLib '.';
%let oil09temp=oilLib.oil09;


data oil09;
   set &oil09temp;
   if (bpm eq 0) then do;
      bpm = 1e-6;
   end;
   logbpm = log(bpm);
   if ((LonBot > -94)   and (LonBot <-87.7) and
       (LatBot <  29.8) and (LatBot > 27.1)    ) then do;
      output;
   end;
   label logbpm='Log Barels per Month';
run;

ods graphics on;

proc variogram data=oil09 plots(only)=(observations equate);
   compute lagdistance=0.35 maxlag=9;
   coord xc=LonBot yc=LatBot;
   var bpm;
run;


proc variogram data=oil09 plots(only)=(fit equate);
   store out=OilStore / label='Gulf Oil 2009 Correlation Model';
   compute lagdistance=0.35 maxlag=9;
   coord xc=LonBot yc=LatBot;
   var logbpm;
   model form=(exp);
   parms (28) (20) (0.25);
run;

proc krige2d data=oil09 outest=outOil
                        plots(only)=(equate pred(fill=pred line=se));
   store in=OilStore;
   coord xc=LonBot yc=LatBot;
   grid x=-94 to -87.7 by 0.1 y=27.1 to 29.8 by 0.1;
   predict var=logbpm radius=1 minpoints=1 maxpoints=50;
   model storeselect;
run;

ods graphics off;
